pub struct BigVec<'data> {
    pub data: &'data mut [u8],
}
Contains easy to use utilities for a big vector of Borsh-compatible types, to avoid managing the entire struct on-chain and blow through stack limits.

Fields

data: &'data mut [u8]

Underlying data buffer, pieces of which are serialized

Implementations

Get the length of the vector

Find out if the vector has no contents (as demanded by clippy)

Retain all elements that match the provided function, discard all others

Extracts a slice of the data types

Add new element to the end

Get an iterator for the type provided

Get a mutable iterator for the type provided

Find matching data in the array

Find matching data in the array