StakeStatus

Enum StakeStatus 

pub enum StakeStatus {
    Active,
    DeactivatingTransient,
    ReadyForRemoval,
    DeactivatingValidator,
    DeactivatingAll,
}
Status of the stake account in the validator list, for accounting

Variants



Active

Stake account is active, there may be a transient stake as well



DeactivatingTransient

Only transient stake account exists, when a transient stake is deactivating during validator removal



ReadyForRemoval

No more validator stake accounts exist, entry ready for removal during UpdateStakePoolBalance



DeactivatingValidator

Only the validator stake account is deactivating, no transient stake account exists



DeactivatingAll

Both the transient and validator stake account are deactivating, when a validator is removed with a transient stake active

Implementations

Source

impl StakeStatus

pub fn remove_validator_stake(&mut self)

Downgrade the status towards ready for removal by removing the validator stake

pub fn remove_transient_stake(&mut self)

Downgrade the status towards ready for removal by removing the transient stake