pub struct PodStakeStatus(/* private fields */);Expand description
Wrapper struct that can be Pod, containing a byte that should be a valid
StakeStatus underneath.
Implementations
Sourceimpl PodStakeStatus
impl PodStakeStatus
Sourcepub fn remove_validator_stake(&mut self) -> Result<(), ProgramError>
pub fn remove_validator_stake(&mut self) -> Result<(), ProgramError>
Downgrade the status towards ready for removal by removing the validator stake
Sourcepub fn remove_transient_stake(&mut self) -> Result<(), ProgramError>
pub fn remove_transient_stake(&mut self) -> Result<(), ProgramError>
Downgrade the status towards ready for removal by removing the transient stake