Struct spl_stake_pool::state::ValidatorList
source · [−]#[repr(C)]pub struct ValidatorList {
pub header: ValidatorListHeader,
pub validators: Vec<ValidatorStakeInfo>,
}Expand description
Storage list for all validator stake accounts in the pool.
Fields
header: ValidatorListHeaderData outside of the validator list, separated out for cheaper deserializations
validators: Vec<ValidatorStakeInfo>List of stake info for each validator in the pool
Implementations
sourceimpl ValidatorList
impl ValidatorList
sourcepub fn new(max_validators: u32) -> Self
pub fn new(max_validators: u32) -> Self
Create an empty instance containing space for max_validators and preferred validator keys
sourcepub fn calculate_max_validators(buffer_length: usize) -> usize
pub fn calculate_max_validators(buffer_length: usize) -> usize
Calculate the number of validator entries that fit in the provided length
sourcepub fn contains(&self, vote_account_address: &Pubkey) -> bool
pub fn contains(&self, vote_account_address: &Pubkey) -> bool
Check if contains validator with particular pubkey
sourcepub fn find_mut(
&mut self,
vote_account_address: &Pubkey
) -> Option<&mut ValidatorStakeInfo>
pub fn find_mut(
&mut self,
vote_account_address: &Pubkey
) -> Option<&mut ValidatorStakeInfo>
Check if contains validator with particular pubkey
sourcepub fn find(&self, vote_account_address: &Pubkey) -> Option<&ValidatorStakeInfo>
pub fn find(&self, vote_account_address: &Pubkey) -> Option<&ValidatorStakeInfo>
Check if contains validator with particular pubkey
sourcepub fn has_active_stake(&self) -> bool
pub fn has_active_stake(&self) -> bool
Check if the list has any active stake