#[repr(C)]
pub struct ValidatorStakeInfo { pub active_stake_lamports: u64, pub transient_stake_lamports: u64, pub last_update_epoch: u64, pub transient_seed_suffix_start: u64, pub transient_seed_suffix_end: u64, pub status: StakeStatus, pub vote_account_address: Pubkey, }
Information about a validator in the pool

NOTE: ORDER IS VERY IMPORTANT HERE, PLEASE DO NOT RE-ORDER THE FIELDS UNLESS THERE’S AN EXTREMELY GOOD REASON.

To save on BPF instructions, the serialized bytes are reinterpreted with an unsafe pointer cast, which means that this structure cannot have any undeclared alignment-padding in its representation.

Fields

active_stake_lamports: u64

Amount of active stake delegated to this validator, minus the minimum required stake amount of rent-exemption + crate::MINIMUM_ACTIVE_STAKE (currently 0.001 SOL).

Note that if last_update_epoch does not match the current epoch then this field may not be accurate

transient_stake_lamports: u64

Amount of transient stake delegated to this validator

Note that if last_update_epoch does not match the current epoch then this field may not be accurate

last_update_epoch: u64

Last epoch the active and transient stake lamports fields were updated

transient_seed_suffix_start: u64

Start of the validator transient account seed suffixess

transient_seed_suffix_end: u64

End of the validator transient account seed suffixes

status: StakeStatus

Status of the validator stake account

vote_account_address: Pubkey

Validator vote account address

Implementations

Get the total lamports delegated to this validator (active and transient)

Performs a very cheap comparison, for checking if this validator stake info matches the vote account address

Performs a very cheap comparison, for checking if this validator stake info does not have active lamports equal to the given bytes

Performs a very cheap comparison, for checking if this validator stake info does not have lamports equal to the given bytes

Check that the validator stake info is valid