Instruction types
Enums
- Funding
Type - Defines which authority to update in the
SetFundingAuthorityinstruction - Preferred
Validator Type - Defines which validator vote account is set during the
SetPreferredValidatorinstruction - Stake
Pool Instruction - Instructions supported by the
StakePoolprogram.
Functions
- add_
validator_ to_ pool - Creates
AddValidatorToPoolinstruction (add new validator stake account to the pool) - add_
validator_ to_ pool_ with_ vote - Create an
AddValidatorToPoolinstruction given an existing stake pool and vote account - cleanup_
removed_ validator_ entries - Creates
CleanupRemovedValidatorEntriesinstruction (removes entries from the validator list) - create_
token_ metadata - Creates an instruction to create metadata using the mpl token metadata program for the pool token
- decrease_
additional_ validator_ stake - Creates
DecreaseAdditionalValidatorStakeinstruction (rebalance from validator account to transient account) - decrease_
additional_ validator_ stake_ with_ list - Create a
DecreaseAdditionalValidatorStakeinstruction given an existing stake pool, validator list and vote account - decrease_
additional_ validator_ stake_ with_ vote - Create a
DecreaseAdditionalValidatorStakeinstruction given an existing stake pool and vote account - decrease_
validator_ stake Deprecated - Creates
DecreaseValidatorStakeinstruction (rebalance from validator account to transient account) - decrease_
validator_ stake_ with_ reserve - Creates
DecreaseValidatorStakeWithReserveinstruction (rebalance from validator account to transient account) - decrease_
validator_ stake_ with_ vote - Create a
DecreaseValidatorStakeinstruction given an existing stake pool and vote account - deposit_
sol - Creates instruction to deposit SOL directly into a stake pool.
- deposit_
sol_ with_ authority - Creates instruction required to deposit SOL directly into a stake pool.
The difference with
deposit_sol()is that a deposit authority must sign this instruction. - deposit_
sol_ with_ authority_ and_ slippage - Creates instruction to deposit SOL directly into a stake pool with slippage constraint.
- deposit_
sol_ with_ slippage - Creates instruction to deposit SOL directly into a stake pool with slippage constraint.
- deposit_
stake - Creates instructions required to deposit into a stake pool, given a stake account owned by the user.
- deposit_
stake_ with_ authority - Creates instructions required to deposit into a stake pool, given a stake
account owned by the user. The difference with
deposit()is that a deposit authority must sign this instruction, which is required for private pools. - deposit_
stake_ with_ authority_ and_ slippage - Creates instructions required to deposit into a stake pool with slippage,
given a stake account owned by the user. The difference with
deposit()is that a deposit authority must sign this instruction, which is required for private pools. - deposit_
stake_ with_ slippage - Creates instructions to deposit into a stake pool with slippage
- deposit_
wsol_ with_ session - Creates instruction required to deposit wSOL directly into a stake pool using a session signer.
- increase_
additional_ validator_ stake - Creates
IncreaseAdditionalValidatorStakeinstruction (rebalance from reserve account to transient account) - increase_
additional_ validator_ stake_ with_ list - Create a
IncreaseAdditionalValidatorStakeinstruction given an existing stake pool, validator list and vote account - increase_
additional_ validator_ stake_ with_ vote - Create an
IncreaseAdditionalValidatorStakeinstruction given an existing stake pool and vote account - increase_
validator_ stake - Creates
IncreaseValidatorStakeinstruction (rebalance from reserve account to transient account) - increase_
validator_ stake_ with_ vote - Create an
IncreaseValidatorStakeinstruction given an existing stake pool and vote account - initialize
- Creates an
Initializeinstruction. - redelegate
Deprecated - Creates
Redelegateinstruction (rebalance from one validator account to another) - remove_
validator_ from_ pool - Creates
RemoveValidatorFromPoolinstruction (remove validator stake account from the pool) - remove_
validator_ from_ pool_ with_ vote - Create an
RemoveValidatorFromPoolinstruction given an existing stake pool and vote account - set_fee
- Creates a
SetFeeinstruction. - set_
funding_ authority - Creates a
SetFundingAuthorityinstruction. - set_
manager - Creates a
SetManagerinstruction. - set_
preferred_ validator - Creates
SetPreferredDepositValidatorinstruction - set_
staker - Creates a
SetStakerinstruction. - update_
stake_ pool - Creates all
UpdateValidatorListBalanceandUpdateStakePoolBalanceinstructions for fully updating a stake pool each epoch - update_
stake_ pool_ balance - Creates
UpdateStakePoolBalanceinstruction (pool balance from the stake account list balances) - update_
stale_ stake_ pool - Creates the
UpdateValidatorListBalanceinstructions only for validators onvalidator_listthat have not been updated for this epoch, and theUpdateStakePoolBalanceinstruction for fully updating the stake pool. - update_
stale_ validator_ list_ balance_ chunk - Creates
UpdateValidatorListBalanceinstruction (update validator stake account balances) - update_
token_ metadata - Creates an instruction to update metadata in the mpl token metadata program account for the pool token
- update_
validator_ list_ balance Deprecated - Creates
UpdateValidatorListBalanceinstruction (update validator stake account balances) - update_
validator_ list_ balance_ chunk - Creates an
UpdateValidatorListBalanceinstruction (update validator stake account balances) to updatevalidator_list[start_index..start_index + len]. - withdraw_
from_ stake_ account_ with_ session - Creates instruction to withdraw lamports from a user stake account using a session signer. Used after the cooldown period to convert deactivated stake to SOL.
- withdraw_
sol - Creates instruction required to withdraw SOL directly from a stake pool.
- withdraw_
sol_ with_ authority - Creates instruction required to withdraw SOL directly from a stake pool.
The difference with
withdraw_sol()is that the sol withdraw authority must sign this instruction. - withdraw_
sol_ with_ authority_ and_ slippage - Creates instruction required to withdraw SOL directly from a stake pool with
a slippage constraint.
The difference with
withdraw_sol()is that the sol withdraw authority must sign this instruction. - withdraw_
sol_ with_ slippage - Creates instruction required to withdraw SOL directly from a stake pool with slippage constraints.
- withdraw_
stake - Creates a
WithdrawStakeinstruction. - withdraw_
stake_ with_ session - Creates instruction to withdraw stake from a stake pool using a session signer.
- withdraw_
stake_ with_ slippage - Creates a
WithdrawStakeWithSlippageinstruction. - withdraw_
wsol_ with_ session - Creates instruction required to withdraw wSOL directly from a stake pool using a session signer.