Enum spl_stake_pool::state::AccountType
source · [−]pub enum AccountType {
Uninitialized,
StakePool,
ValidatorList,
}Expand description
Enum representing the account type managed by the program
Variants
Uninitialized
If the account has not been initialized, the enum will be 0
StakePool
Stake pool
ValidatorList
Validator stake list