Enum spl_stake_pool::state::StakeStatus
source · [−]pub enum StakeStatus {
Active,
DeactivatingTransient,
ReadyForRemoval,
}Expand description
Status of the stake account in the validator list, for accounting
Variants
Active
Stake account is active, there may be a transient stake as well
DeactivatingTransient
Only transient stake account exists, when a transient stake is deactivating during validator removal
ReadyForRemoval
No more validator stake accounts exist, entry ready for removal during
UpdateStakePoolBalance