#[repr(C)]pub struct Fee {
pub denominator: u64,
pub numerator: u64,
}Expand description
Fee rate as a ratio, minted on UpdateStakePoolBalance as a proportion of
the rewards
If either the numerator or the denominator is 0, the fee is considered to be 0
Fields
denominator: u64denominator of the fee ratio
numerator: u64numerator of the fee ratio
Implementations
Sourceimpl Fee
impl Fee
Sourcepub fn apply(&self, amt: u64) -> Option<u128>
pub fn apply(&self, amt: u64) -> Option<u128>
Applies the Fee’s rates to a given amount, amt
returning the amount to be subtracted from it as fees
(0 if denominator is 0 or amt is 0),
or None if overflow occurs
Sourcepub fn check_withdrawal(
&self,
old_withdrawal_fee: &Fee,
) -> Result<(), StakePoolError>
pub fn check_withdrawal( &self, old_withdrawal_fee: &Fee, ) -> Result<(), StakePoolError>
Withdrawal fees have some additional restrictions, this fn checks if those are met, returning an error if not. Does nothing and returns Ok if fee type is not withdrawal