#[repr(C)]
pub struct ValidatorListHeader { pub account_type: AccountType, pub max_validators: u32, }
Helper type to deserialize just the start of a ValidatorList

Fields

account_type: AccountType

Account type, must be ValidatorList currently

max_validators: u32

Maximum allowable number of validators

Implementations

Check if validator stake list is actually initialized as a validator stake list

Check if the validator stake list is uninitialized

Extracts a slice of ValidatorStakeInfo types from the vec part of the ValidatorList

Extracts the validator list into its header and internal BigVec