Struct spl_stake_pool::state::ValidatorListHeader
source · [−]#[repr(C)]pub struct ValidatorListHeader {
pub account_type: AccountType,
pub max_validators: u32,
}Expand description
Helper type to deserialize just the start of a ValidatorList
Fields
account_type: AccountTypeAccount type, must be ValidatorList currently
max_validators: u32Maximum allowable number of validators
Implementations
sourceimpl ValidatorListHeader
impl ValidatorListHeader
sourcepub fn is_valid(&self) -> bool
pub fn is_valid(&self) -> bool
Check if validator stake list is actually initialized as a validator stake list
sourcepub fn is_uninitialized(&self) -> bool
pub fn is_uninitialized(&self) -> bool
Check if the validator stake list is uninitialized
sourcepub fn deserialize_mut_slice(
data: &mut [u8],
skip: usize,
len: usize
) -> Result<(Self, Vec<&mut ValidatorStakeInfo>), ProgramError>
pub fn deserialize_mut_slice(
data: &mut [u8],
skip: usize,
len: usize
) -> Result<(Self, Vec<&mut ValidatorStakeInfo>), ProgramError>
Extracts a slice of ValidatorStakeInfo types from the vec part of the ValidatorList
sourcepub fn deserialize_vec(
data: &mut [u8]
) -> Result<(Self, BigVec<'_>), ProgramError>
pub fn deserialize_vec(
data: &mut [u8]
) -> Result<(Self, BigVec<'_>), ProgramError>
Extracts the validator list into its header and internal BigVec