Struct spl_stake_pool::state::ValidatorStakeInfo
source · [−]#[repr(C)]pub struct ValidatorStakeInfo {
pub active_stake_lamports: u64,
pub transient_stake_lamports: u64,
pub last_update_epoch: u64,
pub transient_seed_suffix_start: u64,
pub transient_seed_suffix_end: u64,
pub status: StakeStatus,
pub vote_account_address: Pubkey,
}Expand description
Information about a validator in the pool
NOTE: ORDER IS VERY IMPORTANT HERE, PLEASE DO NOT RE-ORDER THE FIELDS UNLESS THERE’S AN EXTREMELY GOOD REASON.
To save on BPF instructions, the serialized bytes are reinterpreted with an unsafe pointer cast, which means that this structure cannot have any undeclared alignment-padding in its representation.
Fields
active_stake_lamports: u64Amount of active stake delegated to this validator, minus the minimum
required stake amount of rent-exemption + crate::MINIMUM_ACTIVE_STAKE
(currently 0.001 SOL).
Note that if last_update_epoch does not match the current epoch then
this field may not be accurate
transient_stake_lamports: u64Amount of transient stake delegated to this validator
Note that if last_update_epoch does not match the current epoch then
this field may not be accurate
last_update_epoch: u64Last epoch the active and transient stake lamports fields were updated
transient_seed_suffix_start: u64Start of the validator transient account seed suffixess
transient_seed_suffix_end: u64End of the validator transient account seed suffixes
status: StakeStatusStatus of the validator stake account
vote_account_address: PubkeyValidator vote account address
Implementations
sourceimpl ValidatorStakeInfo
impl ValidatorStakeInfo
sourcepub fn stake_lamports(&self) -> u64
pub fn stake_lamports(&self) -> u64
Get the total lamports delegated to this validator (active and transient)
sourcepub fn memcmp_pubkey(data: &[u8], vote_address_bytes: &[u8]) -> bool
pub fn memcmp_pubkey(data: &[u8], vote_address_bytes: &[u8]) -> bool
Performs a very cheap comparison, for checking if this validator stake info matches the vote account address
sourcepub fn active_lamports_not_equal(data: &[u8], lamports_le_bytes: &[u8]) -> bool
pub fn active_lamports_not_equal(data: &[u8], lamports_le_bytes: &[u8]) -> bool
Performs a very cheap comparison, for checking if this validator stake info does not have active lamports equal to the given bytes